/*!
 * eocjsNewsticker v0.4.2
 * Copyright (c) 2021 Dieter Schmitt
 * Released under the MIT license - https://opensource.org/licenses/MIT
 */

(function($, window, document, undefined) {
  $.fn.eocjsNewsticker = function(options) {

    // _______ Options _______

    let defaults = {
      speed:     20,
      timeout:   1,
      divider:   '',
      type:      'static',    // static or ajax
      source:    '',          // ajax source (url)
      dataType:  'json',      // data type of the expected file (json or jsonp)
      callback:  'callback',  // used for jsonp
      interval:  120,       // polling interval of the ajax source (seconds)
      reverse: false,
    };
    let settings = $.extend({}, defaults, options);


    // _______ Inner Variables _______

    let self              =  this;
    let content           =  self.html();
    let active            =  'eocjs-newsticker-active';
    let container         =  {};
    let one               =  {};
    let two               =  {};
    let both              =  {};
    let oneNeedsUpdate    =  false;
    let twoNeedsUpdate    =  false;
    let localWindow       =  $(window);
    let localWindowWidth  =  localWindow.width();


    // _______ Init _______

    function init() {
      if (!self.hasClass(active)) {
        create();
        start();
        self.addClass(active);
      }
    }


    // _______ Create _______

    function create() {

      self.addClass('eocjs-newsticker').html('<div class="eocjs-newsticker-container"><div class="eocjs-newsticker-one"></div><div class="eocjs-newsticker-two"></div></div>');

      container  =  self.find('.eocjs-newsticker-container');
      one        =  self.find('.eocjs-newsticker-one');
      two        =  self.find('.eocjs-newsticker-two');
      both       =  self.find('.eocjs-newsticker-one, .eocjs-newsticker-two');

    }


    // _______ Start _______

    function start() {

      if (settings.type === 'static') {

        content = content + ' ' + settings.divider;
        run(content, (settings.timeout * 1000));

      } 
    }


    // _______ Run _______

    function run(content, timeout) {

      update(both, content);

      // check if reverse true 
      if (settings.reverse) {
        two.css({'right': one.width()});
      } else {
        two.css({'left': one.width()});
      }

      setTimeout(function() {

        let width  =  one.width();
        let speed  =  settings.speed * width;

        animateSlide(one, 0, -width, speed);
        animateSlide(two, width, 0, speed);

      }, timeout);

    }


    // _______ Update _______

    function update(slide, content) {

      slide.html(content);
      while (container.width() > slide.width()) {
        slide.append(' ' + content);
      }
      slide.append('&nbsp;');

    }


    // _______ Animation _______

    function animateSlide(slide, start, destination, speed) {

      let dir = null;

      if(settings.reverse) {
        dir = {
          right: destination
        }
      } else {
        dir = {
          left: destination
        }
      }

      slide.animate(
        dir,
        speed,
        'linear',
        function() {

          let width;

          if (start === 0) {

            if (slide === one && oneNeedsUpdate) {
              update(one, content);
              oneNeedsUpdate = false;
            } else if (slide === two && twoNeedsUpdate) {
              update(two, content);
              twoNeedsUpdate = false;
            }

            slide === one ? width = two.width() : width = one.width();
            speed = settings.speed * width;
            settings.reverse ? slide.css({ 'right': width }) : slide.css({ 'left': width });
            animateSlide(slide, width, 0, speed);

          } else {
            slide === one ? width = one.width() : width = two.width();
            speed = settings.speed * width;
            animateSlide(slide, 0, -width, speed);
          }

        }
      );

    }


    // _______ Resize _______

    localWindow.on('resize', function() {
    
      let width = localWindow.width();
      
      if (width != localWindowWidth) {

        if (width > localWindowWidth) {
          if (settings.reverse) {
            if (one.position().right > 0) {
              update(one, content);
              twoNeedsUpdate = true;
            } else if (two.position().right > 0) {
              update(two, content);
              oneNeedsUpdate = true;
            }
          } else {
            if (one.position().left > 0) {
              update(one, content);
              twoNeedsUpdate = true;
            } else if (two.position().left > 0) {
              update(two, content);
              oneNeedsUpdate = true;
            }
          }
        } else {
          oneNeedsUpdate = true;
          twoNeedsUpdate = true;
        }

        localWindowWidth = width;

      }
      
    });


    // _______ Init _______

    init();

    return this;

  };
})(jQuery, window, document);
