<?php

/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */

 /**
 * Only return default value if we don't have a post ID (in the 'post' query variable)
 *
 * @param  bool  $default On/Off (true/false)
 * @return mixed          Returns true or '', the blank default
 */
function huntar_set_checkbox_default_for_new_post( $default ) {
    return isset( $_GET['post'] ) ? '' : ( $default ? (string) $default : '' );
}

add_action( 'cmb2_admin_init', 'huntar_register_metabox' );

/**
 * Hook in and add a demo metabox. Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */

function huntar_register_metabox() {

    $prefix = '_huntar_';

    $prefixpage = '_huntarpage_';
    
    
    $huntar_post_meta = new_cmb2_box( array(
        'id'            => $prefixpage . 'blog_post_control',
        'title'         => esc_html__( 'Post Thumb Controller', 'huntar' ),
        'object_types'  => array( 'post' ), // Post type
        'closed'        => true
    ) );
    $huntar_post_meta->add_field( array(
        'name' => esc_html__( 'Post Format Video', 'huntar' ),
        'desc' => esc_html__( 'Use This Field When Post Format Video', 'huntar' ),
        'id'   => $prefix . 'post_format_video',
        'type' => 'text_url',
    ) );
    $huntar_post_meta->add_field( array(
        'name' => esc_html__( 'Post Format Audio', 'huntar' ),
        'desc' => esc_html__( 'Use This Field When Post Format Audio', 'huntar' ),
        'id'   => $prefix . 'post_format_audio',
        'type' => 'oembed',
    ) );
    $huntar_post_meta->add_field( array(
        'name' => esc_html__( 'Post Thumbnail For Slider', 'huntar' ),
        'desc' => esc_html__( 'Use This Field When You Want A Slider In Post Thumbnail', 'huntar' ),
        'id'   => $prefix . 'post_format_slider',
        'type' => 'file_list',
    ) );
    
    $huntar_page_meta = new_cmb2_box( array(
        'id'            => $prefixpage . 'page_meta_section',
        'title'         => esc_html__( 'Page Meta', 'huntar' ),
        'object_types'  => array( 'page' ), // Post type
        'closed'        => true
    ) );

    $huntar_page_meta->add_field( array(
        'name' => esc_html__( 'Page Breadcrumb Area', 'huntar' ),
        'desc' => esc_html__( 'check to display page breadcrumb area.', 'huntar' ),
        'id'   => $prefix . 'page_breadcrumb_area',
        'type' => 'select',
        'default' => '1',
        'options'   => array(
            '1'   => esc_html__('Show','huntar'),
            '2'     => esc_html__('Hide','huntar'),
        )
    ) );


    $huntar_page_meta->add_field( array(
        'name' => esc_html__( 'Page Breadcrumb Settings', 'huntar' ),
        'id'   => $prefix . 'page_breadcrumb_settings',
        'type' => 'select',
        'default'   => 'global',
        'options'   => array(
            'global'   => esc_html__('Global Settings','huntar'),
            'page'     => esc_html__('Page Settings','huntar'),
        )
    ) );

    $huntar_page_meta->add_field( array(
        'name'    => esc_html__( 'Breadcumb Image', 'huntar' ),
        'desc'    => esc_html__( 'Upload an image or enter an URL.', 'huntar' ),
        'id'      => $prefix . 'breadcumb_image',
        'type'    => 'file',
        // Optional:
        'options' => array(
            'url' => false, // Hide the text input for the url
        ),
        'text'    => array(
            'add_upload_file_text' => __( 'Add File', 'huntar' ) // Change upload button text. Default: "Add or Upload File"
        ),
        'preview_size' => 'large', // Image size to use when previewing in the admin.
    ) );

    $huntar_page_meta->add_field( array(
        'name' => esc_html__( 'Page Title', 'huntar' ),
        'desc' => esc_html__( 'check to display Page Title.', 'huntar' ),
        'id'   => $prefix . 'page_title',
        'type' => 'select',
        'default' => '1',
        'options'   => array(
            '1'   => esc_html__('Show','huntar'),
            '2'     => esc_html__('Hide','huntar'),
        )
    ) );

    $huntar_page_meta->add_field( array(
        'name' => esc_html__( 'Page Title Settings', 'huntar' ),
        'id'   => $prefix . 'page_title_settings',
        'type' => 'select',
        'options'   => array(
            'default'  => esc_html__('Default Title','huntar'),
            'custom'  => esc_html__('Custom Title','huntar'),
        ),
        'default'   => 'default'
    ) );

    $huntar_page_meta->add_field( array(
        'name' => esc_html__( 'Custom Page Title', 'huntar' ),
        'id'   => $prefix . 'custom_page_title',
        'type' => 'text'
    ) );

    $huntar_page_meta->add_field( array(
        'name' => esc_html__( 'Breadcrumb', 'huntar' ),
        'desc' => esc_html__( 'Select Show to display breadcrumb area', 'huntar' ),
        'id'   => $prefix . 'page_breadcrumb_trigger',
        'type' => 'switch_btn',
        'default' => huntar_set_checkbox_default_for_new_post( true ),
    ) );

    $huntar_layout_meta = new_cmb2_box( array(
        'id'            => $prefixpage . 'page_layout_section',
        'title'         => esc_html__( 'Page Layout', 'huntar' ),
        'context'       => 'side',
        'priority'      => 'high',
        'object_types'  => array( 'page' ), // Post type
        'closed'        => true
    ) );

    $huntar_layout_meta->add_field( array(
        'desc'       => esc_html__( 'Set page layout container,container fluid,fullwidth or both. It\'s work only in template builder page.', 'huntar' ),
        'id'         => $prefix . 'custom_page_layout',
        'type'       => 'radio',
        'options' => array(
            '1' => esc_html__( 'Container', 'huntar' ),
            '2' => esc_html__( 'Container Fluid', 'huntar' ),
            '3' => esc_html__( 'Fullwidth', 'huntar' ),
        ),
    ) );

    $huntar_page_style = new_cmb2_box( array(
        'id'            => $prefixpage . 'page_style_section',
        'title'         => esc_html__( 'Page Style', 'huntar' ),
        'object_types'  => array( 'page' ), // Post type
        'closed'        => true
    ) );
    $huntar_page_style->add_field( array(
        'name' => esc_html__( 'Theme Style', 'huntar' ),
        'desc' => esc_html__( 'Select A theme mode from dropdown', 'huntar' ),
        'id'   => $prefix . 'page_theme_style',
        'type' => 'select',
        'default' => '2',
        'options'   => array(
            '1'   => esc_html__('Fishing Theme','huntar'),
            '2'     => esc_html__('Hunting Theme','huntar'),
        )
    ) );

}

add_action( 'cmb2_admin_init', 'huntar_register_taxonomy_metabox' );
/**
 * Hook in and add a metabox to add fields to taxonomy terms
 */
function huntar_register_taxonomy_metabox() {

    $prefix = '_huntar_';
    /**
     * Metabox to add fields to categories and tags
     */
    $huntar_term_meta = new_cmb2_box( array(
        'id'               => $prefix.'term_edit',
        'title'            => esc_html__( 'Category Metabox', 'huntar' ),
        'object_types'     => array( 'term' ),
        'taxonomies'       => array( 'category'),
    ) );
    $huntar_term_meta->add_field( array(
        'name'     => esc_html__( 'Extra Info', 'huntar' ),
        'id'       => $prefix.'term_extra_info',
        'type'     => 'title',
        'on_front' => false,
    ) );
    $huntar_term_meta->add_field( array(
        'name' => esc_html__( 'Category Image', 'huntar' ),
        'desc' => esc_html__( 'Set Category Image', 'huntar' ),
        'id'   => $prefix.'term_avatar',
        'type' => 'file',
        'text'    => array(
            'add_upload_file_text' => esc_html__('Add Image','huntar') // Change upload button text. Default: "Add or Upload File"
        ),
    ) );


    /**
     * Metabox for the user profile screen
     */
    $huntar_user = new_cmb2_box( array(
        'id'               => $prefix.'user_edit',
        'title'            => esc_html__( 'User Profile Metabox', 'huntar' ), // Doesn't output for user boxes
        'object_types'     => array( 'user' ), // Tells CMB2 to use user_meta vs post_meta
        'show_names'       => true,
        'new_user_section' => 'add-new-user', // where form will show on new user page. 'add-existing-user' is only other valid option.
    ) );
    $huntar_user->add_field( array(
        'name'     => esc_html__( 'Social Profile', 'huntar' ),
        'id'       => $prefix.'user_extra_info',
        'type'     => 'title',
        'on_front' => false,
    ) );

    $group_field_id = $huntar_user->add_field( array(
        'id'          => $prefix .'social_profile_group',
        'type'        => 'group',
        'description' => __( 'Social Profile', 'huntar' ),
        'options'     => array(
            'group_title'       => __( 'Social Profile {#}', 'huntar' ), // since version 1.1.4, {#} gets replaced by row number
            'add_button'        => __( 'Add Another Social Profile', 'huntar' ),
            'remove_button'     => __( 'Remove Social Profile', 'huntar' ),
            'closed'         => true
        ),
    ) );

    $huntar_user->add_group_field( $group_field_id, array(
        'name'        => __( 'Icon Class', 'huntar' ),
        'id'          => $prefix .'social_profile_icon',
        'type'        => 'text', // This field type
    ) );

    $huntar_user->add_group_field( $group_field_id, array(
        'desc'       => esc_html__( 'Set social profile link.', 'huntar' ),
        'id'         => $prefix . 'lawyer_social_profile_link',
        'name'       => esc_html__( 'Social Profile link', 'huntar' ),
        'type'       => 'text'
    ) );
}
