<?php

/**
 * @Packge     : Huntar
 * @Version    : 1.0
 * @Author     : Vecurosoft
 * @Author URI : https://www.vecurosoft.com/
 *
 */


// Block direct access
if( ! defined( 'ABSPATH' ) ){
    exit;
}

 // theme option callback
function huntar_opt( $id = null, $url = null ){
    global $huntar_opt;

    if( $id && $url ){

        if( isset( $huntar_opt[$id][$url] ) && $huntar_opt[$id][$url] ){
            return $huntar_opt[$id][$url];
        }
    }else{
        if( isset( $huntar_opt[$id] )  && $huntar_opt[$id] ){
            return $huntar_opt[$id];
        }
    }
}


// theme logo
function huntar_theme_logo() {
    // escaping allow html
    $allowhtml = array(
        'a'    => array(
            'href' => array()
        ),
        'span' => array(),
        'i'    => array(
            'class' => array()
        )
    );
    $siteUrl = home_url('/');
    if( has_custom_logo() ) {
        $custom_logo_id = get_theme_mod( 'custom_logo' );
        $siteLogo = '';
        $siteLogo .= '<a class="logo" href="'.esc_url( $siteUrl ).'">';
        $siteLogo .= huntar_img_tag( array(
            "class" => "img-fluid",
            "url"   => esc_url( wp_get_attachment_image_url( $custom_logo_id, 'full') )
        ) );
        $siteLogo .= '</a>';

        return $siteLogo;
    } elseif( !huntar_opt('huntar_text_title') && huntar_opt('huntar_site_logo', 'url' )  ){

        $siteLogo = '<img class="img-fluid" src="'.esc_url( huntar_opt('huntar_site_logo', 'url' ) ).'" alt="'.esc_attr__( 'logo', 'huntar' ).'" />';
        return '<a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses_post( $siteLogo ).'</a>';


    }elseif( huntar_opt('huntar_text_title') ){
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses( huntar_opt('huntar_text_title'), $allowhtml ).'</a></h2>';
    }else{
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.esc_html( get_bloginfo('name') ).'</a></h2>';
    }
}

// custom meta id callback
function huntar_meta( $id = '' ){
    $value = get_post_meta( get_the_ID(), '_huntar_'.$id, true );
    return $value;
}


// Blog Date Permalink
function huntar_blog_date_permalink() {
    $year  = get_the_time('Y');
    $month_link = get_the_time('m');
    $day   = get_the_time('d');
    $link = get_day_link( $year, $month_link, $day);
    return $link;
}

//audio format iframe match
function huntar_iframe_match() {
    $audio_content = huntar_embedded_media( array('audio', 'iframe') );
    $iframe_match = preg_match("/\iframe\b/i",$audio_content, $match);
    return $iframe_match;
}


//Post embedded media
function huntar_embedded_media( $type = array() ){
    $content = do_shortcode( apply_filters( 'the_content', get_the_content() ) );
    $embed   = get_media_embedded_in_content( $content, $type );


    if( in_array( 'audio' , $type) ){
        if( count( $embed ) > 0 ){
            $output = str_replace( '?visual=true', '?visual=false', $embed[0] );
        }else{
           $output = '';
        }

    }else{
        if( count( $embed ) > 0 ){
            $output = $embed[0];
        }else{
           $output = '';
        }
    }
    return $output;
}


// WP post link pages
function huntar_link_pages(){
    wp_link_pages( array(
        'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'huntar' ) . '</span>',
        'after'       => '</div>',
        'link_before' => '<span>',
        'link_after'  => '</span>',
        'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'huntar' ) . ' </span>%',
        'separator'   => '<span class="screen-reader-text">, </span>',
    ) );
}


// Data Background image attr
function huntar_data_bg_attr( $imgUrl = '' ){
    return 'data-bg-img="'.esc_url( $imgUrl ).'"';
}

// image alt tag
function huntar_image_alt( $url = '' ){
    if( $url != '' ){
        // attachment id by url
        $attachmentid = attachment_url_to_postid( esc_url( $url ) );
       // attachment alt tag
        $image_alt = get_post_meta( esc_html( $attachmentid ) , '_wp_attachment_image_alt', true );
        if( $image_alt ){
            return $image_alt ;
        }else{
            $filename = pathinfo( esc_url( $url ) );
            $alt = str_replace( '-', ' ', $filename['filename'] );
            return $alt;
        }
    }else{
       return;
    }
}


// Flat Content wysiwyg output with meta key and post id

function huntar_get_textareahtml_output( $content ) {
    global $wp_embed;

    $content = $wp_embed->autoembed( $content );
    $content = $wp_embed->run_shortcode( $content );
    $content = wpautop( $content );
    $content = do_shortcode( $content );

    return $content;
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */

function huntar_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'huntar_pingback_header' );


// Excerpt More
function huntar_excerpt_more( $more ) {
    return '...';
}

add_filter( 'excerpt_more', 'huntar_excerpt_more' );


// huntar comment template callback
function huntar_comment_callback( $comment, $args, $depth ) {
        $add_below = 'comment';
    ?>
    <li <?php comment_class( array('vs-comment-item') ); ?>>
        <div id="comment-<?php comment_ID() ?>" class="vs-post-comment d-sm-flex">
            <?php
                if( get_avatar( $comment, 100 )  ) :
            ?>
            <!-- Author Image -->
            <div class="comment-avater">
                <?php
                    if ( $args['avatar_size'] != 0 ) {
                        echo get_avatar( $comment, 100 );
                    }
                ?>
            </div>
            <!-- Author Image -->
            <?php
                endif;
            ?>
            <!-- Comment Content -->
            <div class="comment-content">
                <div class="comment-author">
                    <span class="commented-on fs-12"> <?php printf( esc_html__('%1$s', 'huntar'), get_comment_date() ); ?> </span>
                    <h4 class="name h4"><?php echo esc_html( ucwords( get_comment_author() ) ); ?></h4>
                    <p class="text"><?php echo get_comment_text(); ?></p>
                    <div class="reply_and_edit">
                        <?php
                            $reply_text = '<i class="fal fa-reply"></i>'.esc_html__( 'Reply', 'huntar' ).'';
                            $edit_reply_text = '<i class="far fa-pencil-alt"></i>'.esc_html__( 'Edit', 'huntar' ).'';
                            comment_reply_link(array_merge( $args, array( 'add_below' => $add_below, 'depth' => 3, 'max_depth' => 5, 'reply_text' => $reply_text ) ) );
                        ?>
                        <span class="comment-edit-link pl-10"><?php edit_comment_link( $edit_reply_text, '  ', '' ); ?></span>
                    </div>
                </div>
                
                <?php if ( $comment->comment_approved == '0' ) : ?>
                <p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'huntar' ); ?></p>
                <?php endif; ?>
            </div>
        </div>
        <!-- Comment Content -->
<?php
}

//body class
add_filter( 'body_class', 'huntar_body_class' );
function huntar_body_class( $classes ) {
    if( class_exists('ReduxFramework') ) {
        $huntar_blog_single_sidebar = huntar_opt('huntar_blog_single_sidebar');
        if( ($huntar_blog_single_sidebar != '2' && $huntar_blog_single_sidebar != '3' ) || ! is_active_sidebar('huntar-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }

        $huntar_page_style = huntar_meta('page_theme_style');
        if( $huntar_page_style == 1 ){
            $classes[] = 'theme-fishing';
        }else{
            $classes[] = 'theme-hunting';
        }

    } else {
        if( !is_active_sidebar('huntar-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
    }
    return $classes;
}


function huntar_footer_global_option(){

    // Huntar Widget Enable Disable
    if( class_exists( 'ReduxFramework' ) && ( is_active_sidebar( 'huntar-footer-1' ) || is_active_sidebar( 'huntar-footer-2' ) || is_active_sidebar( 'huntar-footer-3' ) ) ){
        $huntar_footer_widget_enable = huntar_opt( 'huntar_footerwidget_enable' );
    }else{
        $huntar_footer_widget_enable = '';
    }

    // Huntar Footer Bottom Enable Disable
    if( class_exists( 'ReduxFramework' ) ){
        $huntar_footer_bottom_active = huntar_opt( 'huntar_disable_footer_bottom' );
    }else{
        $huntar_footer_bottom_active = '1';
    }
    // Huntar Animation Image for footer
    $animation_footer_image = huntar_opt('huntar_footer_animation_image', 'url');

    $allowhtml = array(
        'p'         => array(
            'class'     => array()
        ),
        'span'      => array(
            'class'     => array(),
        ),
        'a'         => array(
            'href'      => array(),
            'title'     => array(),
            'class'     => array(),
        ),
        'br'        => array(),
        'em'        => array(),
        'strong'    => array(),
        'b'         => array(),
    );
    if( $huntar_footer_widget_enable == '1' || $huntar_footer_bottom_active == '1' ){


        echo '<!---footer-wrapper start-->';
        echo '<div class="bg2 footer-custom-style space-top space-md-top">';
            echo '<footer class="footer-wrapper footer-layout3">';
                echo '<img class="fot-shape1" src="'.esc_url($animation_footer_image).'" alt="'.esc_html__('Huntar', 'huntar').'">';
                if( ( is_active_sidebar( 'huntar-footer-1' ) || is_active_sidebar( 'huntar-footer-2' ) || is_active_sidebar( 'huntar-footer-3' ) ) ) {
                    echo '<div class="container">';
                        echo '<div class="widget-area space-bottom space-md-bottom">';
                            echo '<div class="row align-items-start justify-content-between">';

                                if( is_active_sidebar( 'huntar-footer-1' ) ) :
                                    echo '<div class="col-xl-4 col-lg-4 col-md-8 offset-md-2 offset-lg-0 offset-xl-0">';
                                        dynamic_sidebar( 'huntar-footer-1' );
                                    echo '</div>';
                                endif;
                                if( is_active_sidebar( 'huntar-footer-2' ) ) :
                                    echo '<div class="col-xl-3 col-lg-4 col-md-6">';
                                        dynamic_sidebar( 'huntar-footer-2' );
                                    echo '</div>';
                                endif;
                                if( is_active_sidebar( 'huntar-footer-3' ) ) :
                                    echo '<div class="col-xl-4 col-lg-4 col-md-6">';
                                        dynamic_sidebar( 'huntar-footer-3' );
                                    echo '</div>';
                                endif;                               
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
                if( $huntar_footer_bottom_active == '1' ){
                    echo '<div class="copyright bg-theme-custom pt-25 pb-25">';
                        echo '<div class="container">';
                            echo '<div class="row align-items-center">';
                                echo '<div class="col-lg-6 col-md-6">';
                                    echo '<div class="copyright-text">';
                                        echo '<p class="mb-0 link-inherit fs-16 fw-light text-white">'.wp_kses( huntar_opt( 'huntar_copyright_text' ), $allowhtml ).'</p>';
                                    echo '</div>';
                                echo '</div>';
                                if( has_nav_menu( 'footer-menu' ) ){
                                    echo '<div class="col-lg-6 col-md-6 text-start text-md-end">';
                                        wp_nav_menu( array(
                                            "theme_location"    => 'footer-menu',
                                            "container"         => '',
                                            "menu_class"        => 'menu list-style-none'
                                        ) );
                                    echo '</div>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</footer>';
        echo '</div>';
        echo '<!---footer-wrapper end-->';
    }
}

function huntar_social_icon(){
    $huntar_social_icon = huntar_opt( 'huntar_social_links' );
    if( ! empty( $huntar_social_icon ) && isset( $huntar_social_icon ) ){
        foreach( $huntar_social_icon as $social_icon ){
            if( ! empty( $social_icon['title'] ) ){
                echo '<a href="'.esc_url( $social_icon['url'] ).'"><i class="'.esc_attr( $social_icon['title'] ).'"></i></a> ';
            }
        }
    }
}

// global header
function huntar_global_header_option() {
    huntar_header_topbar();
    if( class_exists( 'ReduxFramework' ) ){
        $huntar_wishlist_show         = huntar_opt( 'huntar_header_wishlist_icon_switcher' );
        $huntar_cart_show             = huntar_opt( 'huntar_header_cart_icon_switcher' );
        $huntar_offcanvas             = huntar_opt( 'huntar_offcanvas_switcher' );
    }else{
        $huntar_wishlist_show         = '';
        $huntar_cart_show             = '';
        $huntar_offcanvas             = '';
    }
    if( class_exists( 'ReduxFramework' ) ){
      echo '<!--sticky-header-wrap start-->';
        echo '<div class="sticky-header-wrap sticky-header sticky-header3 py-2 py-lg-1">';
            echo '<div class="container position-relative">';
                echo '<div class="row align-items-center">';

                    echo '<div class="col-5 col-md-3">';
                        echo '<div class="logo">';
                            echo huntar_theme_logo();
                        echo '</div>';
                    echo '</div>';

                    echo '<div class="col-7 col-md-9 text-end position-static">';
                        if( has_nav_menu( 'primary-menu' ) ) {
                            echo '<nav class="main-menu menu-sticky3 d-none d-lg-block link-inherit">';
                                wp_nav_menu( array(
                                    "theme_location"    => 'primary-menu',
                                    "container"         => '',
                                    "menu_class"        => ''
                                ) );
                            echo '</nav>';
                        }
                        echo '<button class="vs-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</div>';
        echo '<!--sticky-header-wrap end-->';
        echo '<!--vs-mobile-menu start-->';
        echo '<div class="vs-menu-wrapper vs-mobile-menu3">';
            echo '<div class="vs-menu-area">';
                echo '<button class="vs-menu-toggle"><i class="fal fa-times"></i></button>';
                echo '<div class="mobile-logo">';
                    echo huntar_theme_logo();
                echo '</div>';
                if( has_nav_menu( 'mobile-menu' ) ){
                    echo '<div class="vs-mobile-menu">';
                        wp_nav_menu( array(
                            "theme_location"    => 'mobile-menu',
                            "container"         => '',
                            "menu_class"        => ''
                        ) );
                    echo '</div>';
                }
            echo '</div>';
        echo '</div>';
        echo '<!--vs-mobile-menu end-->';
        echo '<!--main-header-area start-->';
        echo '<header class="header-wrapper z-index-step1">';
            echo '<div class="container position-relative">';
                echo '<div class="header3-inner">';
                    echo '<div class="row align-items-center">';
                        echo '<div class="col-xl-2 col-lg-3 col-md-4 col-sm-4 col-6">';
                            echo '<div class="header-logo">';
                                echo huntar_theme_logo();
                            echo '</div>';
                        echo '</div>';
                        echo '<div class="col-xl-10 col-lg-9 col-md-8 col-sm-8 col-6 text-end">';
                            echo '<div class="main-menu-wrapper d-flex align-items-center justify-content-end">';

                                if( has_nav_menu( 'primary-menu' ) ) {
                                    echo '<nav class="main-menu menu-style1 d-none d-xl-inline-block">';
                                        wp_nav_menu( array(
                                            "theme_location"    => 'primary-menu',
                                            "container"         => '',
                                            "menu_class"        => ''
                                        ) );
                                    echo '</nav>';
                                }
                                echo '<div class="d-flex align-items-center justify-content-end py-2">';
                                    echo '<div class="top-widget ml-30 d-none d-md-inline-block">';
                                        if( class_exists( 'woocommerce' ) && class_exists( 'TInvWL_Admin_TInvWL' ) &&  $huntar_wishlist_show == 1 ){
                                            echo do_shortcode('[ti_wishlist_products_counter]');
                                        }
                                        if( class_exists( 'woocommerce' ) &&  $huntar_cart_show == 1 ){
                                            global $woocommerce;
                                            if( ! empty( $woocommerce->cart->cart_contents_count ) ){
                                              $count = $woocommerce->cart->cart_contents_count;
                                            }else{
                                              $count = "0";
                                            }
                                            $cart_page_id = wc_get_page_id( 'cart' );
                                            $cart_page_url = $cart_page_id ? get_permalink( $cart_page_id ) : '';
                                            echo '<a href="'.esc_url( $cart_page_url ).'" class="cart1"><span class="badge">'.esc_html( $count ).'</span><i class="fal fa-shopping-bag"></i></a>';
                                        }

                                    echo '</div>';
                                    if(!empty( huntar_opt( 'huntar_btn_text' ) )){
                                        echo '<div class="right-nav d-none d-sm-inline-block">';
                                            echo '<a class="vs-btn style-3a" href="'.esc_url( huntar_opt( 'huntar_btn_url' ) ).'">'.esc_html( huntar_opt( 'huntar_btn_text' ) ).'</a>';
                                        echo '</div>';
                                    }
                                    if( is_active_sidebar( 'huntar-offcanvas' ) && $huntar_offcanvas == 1 ){
                                        echo '<div class="side-menu ml-10 d-none d-xl-inline-block">';
                                            echo '<button type="button" class="vs-side-menu-toggle sideMenuToggler"><i class="far fa-bars"></i></button>';
                                        echo '</div>';
                                    }
                                    echo '<div class="hambergur-menu hambergur-menu3 ml-10 d-inline-block d-xl-none">';
                                        echo '<button type="button" class="vs-menu-toggle"><i
                                                class="far fa-bars"></i></button>';
                                    echo '</div>';
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</header>';
        echo '<!--main-header-area start-->';

        if( is_active_sidebar( 'huntar-offcanvas' ) ){
            echo '<!--Sidebar start-->';
            echo '<div class="sidemenu-wrapper d-none d-lg-block">';
                echo '<div class="sidemenu-content"><button class="closeButton sideMenuCls"><i class="far fa-times"></i></button>';
                    if( is_active_sidebar( 'huntar-offcanvas' ) ) :
                        dynamic_sidebar( 'huntar-offcanvas' );
                    endif; 
                echo '</div>';
            echo '</div>';
            echo '<!--Sidebar end-->';
        }
    }else{
        huntar_global_header();
    }
}

// huntar woocommerce breadcrumb
function huntar_woo_breadcrumb( $args ) {
    return array(
        'delimiter'   => '',
        'wrap_before' => '<ul class="breadcumb-menu">',
        'wrap_after'  => '</ul>',
        'before'      => '<li>',
        'after'       => '</li>',
        'home'        => _x( 'Home', 'breadcrumb', 'huntar' ),
    );
}

add_filter( 'woocommerce_breadcrumb_defaults', 'huntar_woo_breadcrumb' );

function huntar_custom_search_form( $class ) {
    echo '<!-- Search Form -->';
    echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'" class="'.esc_attr( $class ).'">';
        echo '<label class="searchIcon">';
            echo huntar_img_tag( array(
                "url"   => esc_url( get_theme_file_uri( '/assets/img/search-2.svg' ) ),
                "class" => "svg"
            ) );
            echo '<input value="'.esc_html( get_search_query() ).'" name="s" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'huntar').'">';
        echo '</label>';
    echo '</form>';
    echo '<!-- End Search Form -->';
}



//Fire the wp_body_open action.
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}

//Remove Tag-Clouds inline style
add_filter( 'wp_generate_tag_cloud', 'huntar_remove_tagcloud_inline_style',10,1 );
function huntar_remove_tagcloud_inline_style( $input ){
   return preg_replace('/ style=("|\')(.*?)("|\')/','',$input );
}

function huntar_setPostViews( $postID ) {
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        $count = 0;
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
    }else{
        $count++;
        update_post_meta( $postID, $count_key, $count );
    }
}

function huntar_getPostViews( $postID ){
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
        return __( '0', 'huntar' );
    }
    return $count;
}


/* This code filters the Categories archive widget to include the post count inside the link */
add_filter( 'wp_list_categories', 'huntar_cat_count_span' );
function huntar_cat_count_span( $links ) {
    $links = str_replace('</a> (', '</a> <span class="category-number">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}

/* This code filters the Archive widget to include the post count inside the link */
add_filter( 'get_archives_link', 'huntar_archive_count_span' );
function huntar_archive_count_span( $links ) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="category-number">(', $links);
    $links = str_replace(')', ')</span>', $links);
    return $links;
}

// Huntar Default Header
if( ! function_exists( 'huntar_global_header' ) ){
    function huntar_global_header(){
        echo '<!--sticky-header-wrap start-->';
        echo '<div class="sticky-header-wrap sticky-header sticky-header3 py-2 py-lg-1">';
            echo '<div class="container position-relative">';
                echo '<div class="row align-items-center">';
                    echo '<div class="col-5 col-md-3">';
                        echo '<div class="logo">';
                            echo huntar_theme_logo();
                        echo '</div>';
                    echo '</div>';
                    echo '<div class="col-7 col-md-9 text-end position-static">';
                        if( has_nav_menu( 'primary-menu' ) ) {
                            echo '<nav class="main-menu menu-sticky3 d-none d-lg-block link-inherit">';
                                wp_nav_menu( array(
                                    "theme_location"    => 'primary-menu',
                                    "container"         => '',
                                    "menu_class"        => ''
                                ) );
                            echo '</nav>';
                        }
                        echo '<button class="vs-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</div>';
        echo '<!--sticky-header-wrap end-->';
        echo '<!--vs-mobile-menu start-->';
        echo '<div class="vs-menu-wrapper vs-mobile-menu3">';
            echo '<div class="vs-menu-area">';
                echo '<button class="vs-menu-toggle"><i class="fal fa-times"></i></button>';
                echo '<div class="mobile-logo">';
                    echo huntar_theme_logo();
                echo '</div>';
                if( has_nav_menu( 'mobile-menu' ) ){
                    echo '<div class="vs-mobile-menu">';
                        wp_nav_menu( array(
                            "theme_location"    => 'mobile-menu',
                            "container"         => '',
                            "menu_class"        => ''
                        ) );
                    echo '</div>';
                }
            echo '</div>';
        echo '</div>';
        echo '<!--vs-mobile-menu end-->';
        echo '<!--main-header-area start-->';
        echo '<header class="header-wrapper z-index-step1">';
            echo '<div class="container position-relative">';
                echo '<div class="header3-inner">';
                    echo '<div class="row align-items-center">';
                        echo '<div class="col-xl-2 col-lg-3 col-md-4 col-sm-4 col-6">';
                            echo '<div class="header-logo">';
                                echo huntar_theme_logo();
                            echo '</div>';
                        echo '</div>';
                        echo '<div class="col-xl-10 col-lg-9 col-md-8 col-sm-8 col-6 text-end">';
                            echo '<div class="main-menu-wrapper d-flex align-items-center justify-content-end">';
                                if( has_nav_menu( 'primary-menu' ) ) {
                                    echo '<nav class="main-menu menu-style1 d-none d-xl-inline-block">';
                                        wp_nav_menu( array(
                                            "theme_location"    => 'primary-menu',
                                            "container"         => '',
                                            "menu_class"        => ''
                                        ) );
                                    echo '</nav>';
                                    echo '<div class="d-flex align-items-center justify-content-end py-2">';
                                        echo '<div class="hambergur-menu hambergur-menu3 ml-10 d-inline-block d-xl-none">';
                                            echo '<button type="button" class="vs-menu-toggle"><i
                                                    class="far fa-bars"></i></button>';
                                        echo '</div>';
                                    echo '</div>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</header>';
        echo '<!--main-header-area start-->';
    }
}

if( ! function_exists( 'huntar_header_topbar' ) ){
    function huntar_header_topbar(){
        if( class_exists( 'ReduxFramework' ) ){
            $huntar_show_header_topbar = huntar_opt( 'huntar_header_topbar_switcher' );
            $huntar_language_show      = huntar_opt( 'huntar_language_switcher' );
            $huntar_show_social_icon   = huntar_opt( 'huntar_header_topbar_social_icon_switcher' );
        }else{
            $huntar_show_header_topbar = '';
            $huntar_language_show      = '';
            $huntar_search_show        = '';
            $huntar_show_social_icon   = '';
        }

        if( $huntar_show_header_topbar ){
            $allowhtml = array(
                'a'    => array(
                    'href' => array(),
                    'class' => array()
                ),
                'u'    => array(
                    'class' => array()
                ),
                'span' => array(
                    'class' => array()
                ),
                'i'    => array(
                    'class' => array()
                )
            );

            $email      = huntar_opt( 'huntar_topbar_email' );
            $mobile     = huntar_opt( 'huntar_topbar_phone' );

            $email      = is_email( $email );

            $replace    = array(' ','-',' - ');
            $with       = array('','','');

            $emailurl   = str_replace( $replace, $with, $email );
            $mobileurl  = str_replace( $replace, $with, $mobile );
            $address    = huntar_opt( 'huntar_topbar_address' );
            $address_url    = huntar_opt( 'huntar_topbar_address_location' );

            echo '<!--header-top-wrapper start-->';
            echo '<div class="header-top-wrapper header-top-three d-none d-lg-block">';
                echo '<div class="bg-title2">';
                    echo '<div class="container">';
                        echo '<div class="row align-items-center justify-content-between">';
                            echo '<div class="col-xl-6 col-lg-8 col-md-6 col-sm-6 d-none d-sm-block">';
                                echo '<div class="head-top-links">';
                                    echo '<ul class="list-style-none fs-12 text-white">';
                                        if( ! empty($email ) ){

                                            echo '<li><a href="'.esc_attr( 'mailto:'.$emailurl ).'"><i class="fal fa-envelope"></i> '.esc_html( $email ).'</a></li>';
                                        }
                                        if( ! empty($mobile ) ){
                                            echo '<li><a href="'.esc_attr( 'tel:'.$mobileurl ).'"><i class="fal fa-phone"></i> '.esc_html( $mobile ).'</a></li>';
                                        }
                                        if( ! empty($address ) ){
                                            echo '<li><a href="'.esc_url($address_url).'"><i class="fal fa-map-marker-alt"></i> '.esc_html( $address ).'</a></li>';
                                        }
                                    echo '</ul>';
                                echo '</div>';
                            echo '</div>';
                            echo '<div class="col-xl-6 col-lg-4 col-md-6 col-sm-6 d-flex align-items-center justify-content-end">';
                                echo '<div class="head-top-widget fs-12 mr-40">';
                                    if( class_exists( 'GTranslate' ) && $huntar_language_show == 1 ){
                                        echo '<div class="dropdown">';
                                            echo '<!-- Dropdown -->';
                                            echo '<a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink"
                                            data-bs-toggle="dropdown" aria-expanded="false"><span class="globe-icon"><i
                                                    class="fal fa-globe"></i></span> '.esc_html__('Language', 'huntar').'</a>';
                                            echo '<ul class="dropdown-menu fs-12" aria-labelledby="dropdownMenuLink">';
                                                echo '<li>';
                                                    echo do_shortcode('[gtranslate]');
                                                echo '</li>';
                                            echo '</ul>';
                                        echo '</div>';
                                    }
                                echo '</div>';
                                if( $huntar_show_social_icon ){
                                    echo '<div class="vs-social-group">';
                                        huntar_social_icon();
                                    echo '</div>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
            echo '<!--header-top-wrapper end-->';
        }
    }
}

// Add Extra Class On Comment Reply Button
function huntar_custom_comment_reply_link( $content ) {
    $extra_classes = 'replay-btn';
    return preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $extra_classes, $content);
}

add_filter('comment_reply_link', 'huntar_custom_comment_reply_link', 99);

// Add Extra Class On Edit Comment Link
function huntar_custom_edit_comment_link( $content ) {
    $extra_classes = 'replay-btn';
    return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $extra_classes, $content);
}

add_filter('edit_comment_link', 'huntar_custom_edit_comment_link', 99);


function huntar_post_classes( $classes, $class, $post_id ) {
    if ( get_post_type() === 'post' ) {
        if( ! is_single() ){
            $classes[] = "vs-blog blog-single mb-40";
        }else{
            $classes[] = "blog-details-wrapper mb-30";
        }
    }elseif( get_post_type() === 'product' ){
        // Return Class
    }elseif( get_post_type() === 'page' ){
        $classes[] = "page--item";
    }
    
    return $classes;
}
add_filter( 'post_class', 'huntar_post_classes', 10, 3 );